**********************
*PLEASE CITE PAPER AS:
*Zarach, Z. H., Parteka, A. (2023). Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization. The World Economy

***********************************************
*IF YOU USE REPLICATION PACKAGE PLEASE CITE AS:
*Zarach, Z. H., & Parteka, A. (2023). Data accompanying the paper: "Productivity effects of trade in natural resources – comparison with mechanisms of technological specialization" (Zarach and Parteka, The World Economy, 2023) [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/2cf4-9e23

********************************************************************************************
*THIS DO.FILE PREPARES THE BASELINE DATABASE FOR REGRESSION PART AND FIGURES/TABLES CREATION
********************************************************************************************
clear all
set more off
cd "D:\NR_PRODUCTIVITY\DATA"
use TheWorldEconomy_ZarachParteka_BaselineData.dta, clear

*Creating ID variable
egen countryid=group(countrycode)
order countryid, before(countrycode)

*Calculating labour productivity (LABPROD) variable 
gen labprod = rgdpna/emp
la var labprod "Output per worker at constant 2017 national prices (in 2017US$)"

*Rescaling labour productivity (to avoid scale problems in regression results)
gen labprod_res = labprod/1000
la var labprod_res "Rescaled output per worker (in thousands 2017 USD)"

*Calculating growth of output per worker (labprod) throughout the years
xtset countryid year
bysort countryid: gen glabprod_res = ((labprod_res - l.labprod_res)/l.labprod_res)*100
la var glabprod_res "Growth (in %) of output per worker (labprod)"

*Rescaling the share of natural resource and technological exports (presenting in a percentage form)
foreach k in TOTAL_NR FORESTRY FUEL METAL MINERAL FOUR_IR ICT TECH{
gen share`k' = Sc`k'*100
la var share`k' "share of group `k' in country total exports (in %)"
}

*Calculating percentiles (1st and 99th) of glabprod_res variable
//To be used in robustness chceck estimations (Tables B.13-16 in Appendix B)//
egen p99 = pctile(glabprod_res), p(99)
la var p99 "99th percentile of glabprod_res"
egen p1 = pctile(glabprod_res), p(1)
la var p1 "1st percentile of glabprod_res"

*Preparing labels for plots 
//Specific countries selected by authors//
gen labels = countrycode if countrycode == "POL" | countrycode == "USA" | countrycode == "JPN" | countrycode == "AUS" | countrycode == "KOR" | countrycode == "EGY" | countrycode == "IRN" | countrycode == "FIN" | countrycode == "NOR" | countrycode == "MYS" | countrycode == "SGD" | countrycode == "KWT" | countrycode == "SAU"
la var labels "Labels of selected countries"

*Preparing rescalled variables for plots
//Dividing only by 1.000.000 since BACI CEPII trade values are expressed in thousands USD"
foreach k in EwTOTAL_NR EwTECH EcTOTAL_NR EcTECH{
gen `k'_res = `k'/1000000
la var `k'_res "Variable `k' expressed in billions USD"
}

save TheWorldEconomy_ZarachParteka_PreFinalData.dta, replace
********************************************************************************

*Defining upper adjacent values for RCA index and share of exports (FOUR_IR, ICT, TECH, TOTAL_NR)
//Observations laying outside this value (i.e. outliers) to be removed during creation of two-way scatter plots with the lowess approximation//
//Used specifically in Figure 3 and Figure 4 (as well as Figures A.3-A.6 in Appendix A)//
//For more information on calculating adjacent values please see description of function "adju" in command's "egenmore" documentation//
//Adjacent values calculated for year 1996 as well as 2018 and for whole sample, developed and developing countries//

clear all
//FULL SAMPLE//
foreach w in 1996 2018{
use TheWorldEconomy_ZarachParteka_PreFinalData.dta, clear
foreach k in FOUR_IR ICT TECH TOTAL_NR{
egen upperadj_RCA`k'_`w' = adju(RCA`k') if year==`w'
la var upperadj_RCA`k'_`w' "Upper adjacent value for RCA`k'; full sample year`w'"
egen upperadj_share`k'_`w' = adju(share`k') if year==`w'
la var upperadj_share`k'_`w' "Upper adjacent value for share`k'; full sample year`w'"
xfill upperadj_RCA`k'_`w' upperadj_share`k'_`w', i(countryid)
}
save adjacent_fullsample_`w'.dta, replace
}

//DEVELOPED//
*suffix a in variable name denotes group of developed countries
foreach w in 1996 2018{
use TheWorldEconomy_ZarachParteka_PreFinalData.dta, clear
keep if developed==1
foreach k in FOUR_IR ICT TECH TOTAL_NR{
egen upperadj_RCA`k'_`w'a = adju(RCA`k') if year==`w' 
la var upperadj_RCA`k'_`w'a "Upper adjacent value for RCA`k'; developed group; year`w'"
egen upperadj_share`k'_`w'a = adju(share`k') if year==`w' 
la var upperadj_share`k'_`w'a "Upper adjacent value for share`k'; developed group; year`w'"
xfill upperadj_RCA`k'_`w'a upperadj_share`k'_`w'a, i(countryid)
}
save adjacent_developed_`w'.dta, replace
}

//DEVELOPING//
*suffix b in variable name denotes group of developing countries 
foreach w in 1996 2018{
use TheWorldEconomy_ZarachParteka_PreFinalData.dta, clear
keep if developed!=1
foreach k in FOUR_IR ICT TECH TOTAL_NR{
egen upperadj_RCA`k'_`w'b = adju(RCA`k') if year==`w' 
la var upperadj_RCA`k'_`w'b "Upper adjacent value for RCA`k'; developing group; year`w'"
egen upperadj_share`k'_`w'b = adju(share`k') if year==`w'
la var upperadj_share`k'_`w'b "Upper adjacent value for share`k'; developing group; year`w'" 
xfill upperadj_RCA`k'_`w'b upperadj_share`k'_`w'b, i(countryid)
}
save adjacent_developing_`w'.dta, replace
}

*Merging with main database
use TheWorldEconomy_ZarachParteka_PreFinalData.dta, clear
foreach w in 1996 2018{
foreach k in fullsample developed developing{
merge m:m countryid year using "adjacent_`k'_`w'.dta"
drop _merge
}
}

save TheWorldEconomy_ZarachParteka_FinalData.dta, replace

*Erasing redundant data files
foreach w in 1996 2018{
erase adjacent_developing_`w'.dta
erase adjacent_developed_`w'.dta
erase adjacent_fullsample_`w'.dta
}
erase TheWorldEconomy_ZarachParteka_PreFinalData.dta
